==> 0.20.0.tar.gz: lib/src/theme/loaders/linear_loader/linear_loader_colors.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';

import 'package:moon_design/src/theme/colors.dart';

@immutable
class MoonLinearLoaderColors extends ThemeExtension<MoonLinearLoaderColors> with DiagnosticableTreeMixin {
  static final light = MoonLinearLoaderColors(
    color: MoonColors.light.hit,
    backgroundColor: Colors.transparent,
  );

  static final dark = MoonLinearLoaderColors(
    color: MoonColors.dark.hit,
    backgroundColor: Colors.transparent,
  );

  /// Linear loader color.
  final Color color;

  /// Linear loader background color.
  final Color backgroundColor;

  const MoonLinearLoaderColors({
    required this.color,
    required this.backgroundColor,
  });

  @override
  MoonLinearLoaderColors copyWith({
    Color? color,
    Color? backgroundColor,
  }) {
    return MoonLinearLoaderColors(
      color: color ?? this.color,
      backgroundColor: backgroundColor ?? this.backgroundColor,
    );
  }

  @override
  MoonLinearLoaderColors lerp(ThemeExtension<MoonLinearLoaderColors>? other, double t) {
    if (other is! MoonLinearLoaderColors) return this;

    return MoonLinearLoaderColors(
      color: Color.lerp(color, other.color, t)!,
      backgroundColor: Color.lerp(backgroundColor, other.backgroundColor, t)!,
    );
  }

  @override
  void debugFillProperties(DiagnosticPropertiesBuilder properties) {
    super.debugFillProperties(properties);
    properties
      ..add(DiagnosticsProperty("type", "MoonLinearLoaderColors"))
      ..add(ColorProperty("color", color))
      ..add(ColorProperty("backgroundColor", backgroundColor));
  }
}

==> 0.22.9.tar.gz: lib/src/theme/loaders/linear_loader/linear_loader_colors.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';

import 'package:moon_design/src/theme/colors.dart';
import 'package:moon_design/src/utils/color_premul_lerp.dart';

@immutable
class MoonLinearLoaderColors extends ThemeExtension<MoonLinearLoaderColors> with DiagnosticableTreeMixin {
  static final light = MoonLinearLoaderColors(
    color: MoonColors.light.hit,
    backgroundColor: Colors.transparent,
  );

  static final dark = MoonLinearLoaderColors(
    color: MoonColors.dark.hit,
    backgroundColor: Colors.transparent,
  );

  /// Linear loader color.
  final Color color;

  /// Linear loader background color.
  final Color backgroundColor;

  const MoonLinearLoaderColors({
    required this.color,
    required this.backgroundColor,
  });

  @override
  MoonLinearLoaderColors copyWith({
    Color? color,
    Color? backgroundColor,
  }) {
    return MoonLinearLoaderColors(
      color: color ?? this.color,
      backgroundColor: backgroundColor ?? this.backgroundColor,
    );
  }

  @override
  MoonLinearLoaderColors lerp(ThemeExtension<MoonLinearLoaderColors>? other, double t) {
    if (other is! MoonLinearLoaderColors) return this;

    return MoonLinearLoaderColors(
      color: colorPremulLerp(color, other.color, t)!,
      backgroundColor: colorPremulLerp(backgroundColor, other.backgroundColor, t)!,
    );
  }

  @override
  void debugFillProperties(DiagnosticPropertiesBuilder properties) {
    super.debugFillProperties(properties);
    properties
      ..add(DiagnosticsProperty("type", "MoonLinearLoaderColors"))
      ..add(ColorProperty("color", color))
      ..add(ColorProperty("backgroundColor", backgroundColor));
  }
}
